function noop() { }
function assign(tar, src) {
    // @ts-ignore
    for (const k in src)
        tar[k] = src[k];
    return tar;
}
function run(fn) {
    return fn();
}
function blank_object() {
    return Object.create(null);
}
function run_all(fns) {
    fns.forEach(run);
}
function is_function(thing) {
    return typeof thing === 'function';
}
function safe_not_equal(a, b) {
    return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
}
function is_empty(obj) {
    return Object.keys(obj).length === 0;
}
function create_slot(definition, ctx, $$scope, fn) {
    if (definition) {
        const slot_ctx = get_slot_context(definition, ctx, $$scope, fn);
        return definition[0](slot_ctx);
    }
}
function get_slot_context(definition, ctx, $$scope, fn) {
    return definition[1] && fn
        ? assign($$scope.ctx.slice(), definition[1](fn(ctx)))
        : $$scope.ctx;
}
function get_slot_changes(definition, $$scope, dirty, fn) {
    if (definition[2] && fn) {
        const lets = definition[2](fn(dirty));
        if ($$scope.dirty === undefined) {
            return lets;
        }
        if (typeof lets === 'object') {
            const merged = [];
            const len = Math.max($$scope.dirty.length, lets.length);
            for (let i = 0; i < len; i += 1) {
                merged[i] = $$scope.dirty[i] | lets[i];
            }
            return merged;
        }
        return $$scope.dirty | lets;
    }
    return $$scope.dirty;
}
function update_slot_base(slot, slot_definition, ctx, $$scope, slot_changes, get_slot_context_fn) {
    if (slot_changes) {
        const slot_context = get_slot_context(slot_definition, ctx, $$scope, get_slot_context_fn);
        slot.p(slot_context, slot_changes);
    }
}
function get_all_dirty_from_scope($$scope) {
    if ($$scope.ctx.length > 32) {
        const dirty = [];
        const length = $$scope.ctx.length / 32;
        for (let i = 0; i < length; i++) {
            dirty[i] = -1;
        }
        return dirty;
    }
    return -1;
}
function null_to_empty(value) {
    return value == null ? '' : value;
}

const globals = (typeof window !== 'undefined'
    ? window
    : typeof globalThis !== 'undefined'
        ? globalThis
        : global);
function append(target, node) {
    target.appendChild(node);
}
function insert(target, node, anchor) {
    target.insertBefore(node, anchor || null);
}
function detach(node) {
    if (node.parentNode) {
        node.parentNode.removeChild(node);
    }
}
function element(name) {
    return document.createElement(name);
}
function svg_element(name) {
    return document.createElementNS('http://www.w3.org/2000/svg', name);
}
function text(data) {
    return document.createTextNode(data);
}
function space() {
    return text(' ');
}
function empty() {
    return text('');
}
function listen(node, event, handler, options) {
    node.addEventListener(event, handler, options);
    return () => node.removeEventListener(event, handler, options);
}
function attr(node, attribute, value) {
    if (value == null)
        node.removeAttribute(attribute);
    else if (node.getAttribute(attribute) !== value)
        node.setAttribute(attribute, value);
}
function xlink_attr(node, attribute, value) {
    node.setAttributeNS('http://www.w3.org/1999/xlink', attribute, value);
}
function children(element) {
    return Array.from(element.childNodes);
}
function set_data(text, data) {
    data = '' + data;
    if (text.data === data)
        return;
    text.data = data;
}
function set_style(node, key, value, important) {
    if (value == null) {
        node.style.removeProperty(key);
    }
    else {
        node.style.setProperty(key, value, important ? 'important' : '');
    }
}
function toggle_class(element, name, toggle) {
    element.classList[toggle ? 'add' : 'remove'](name);
}

let current_component;
function set_current_component(component) {
    current_component = component;
}
// TODO figure out if we still want to support
// shorthand events, or if we want to implement
// a real bubbling mechanism
function bubble(component, event) {
    const callbacks = component.$$.callbacks[event.type];
    if (callbacks) {
        // @ts-ignore
        callbacks.slice().forEach(fn => fn.call(this, event));
    }
}

const dirty_components = [];
const binding_callbacks = [];
let render_callbacks = [];
const flush_callbacks = [];
const resolved_promise = /* @__PURE__ */ Promise.resolve();
let update_scheduled = false;
function schedule_update() {
    if (!update_scheduled) {
        update_scheduled = true;
        resolved_promise.then(flush);
    }
}
function add_render_callback(fn) {
    render_callbacks.push(fn);
}
// flush() calls callbacks in this order:
// 1. All beforeUpdate callbacks, in order: parents before children
// 2. All bind:this callbacks, in reverse order: children before parents.
// 3. All afterUpdate callbacks, in order: parents before children. EXCEPT
//    for afterUpdates called during the initial onMount, which are called in
//    reverse order: children before parents.
// Since callbacks might update component values, which could trigger another
// call to flush(), the following steps guard against this:
// 1. During beforeUpdate, any updated components will be added to the
//    dirty_components array and will cause a reentrant call to flush(). Because
//    the flush index is kept outside the function, the reentrant call will pick
//    up where the earlier call left off and go through all dirty components. The
//    current_component value is saved and restored so that the reentrant call will
//    not interfere with the "parent" flush() call.
// 2. bind:this callbacks cannot trigger new flush() calls.
// 3. During afterUpdate, any updated components will NOT have their afterUpdate
//    callback called a second time; the seen_callbacks set, outside the flush()
//    function, guarantees this behavior.
const seen_callbacks = new Set();
let flushidx = 0; // Do *not* move this inside the flush() function
function flush() {
    // Do not reenter flush while dirty components are updated, as this can
    // result in an infinite loop. Instead, let the inner flush handle it.
    // Reentrancy is ok afterwards for bindings etc.
    if (flushidx !== 0) {
        return;
    }
    const saved_component = current_component;
    do {
        // first, call beforeUpdate functions
        // and update components
        try {
            while (flushidx < dirty_components.length) {
                const component = dirty_components[flushidx];
                flushidx++;
                set_current_component(component);
                update(component.$$);
            }
        }
        catch (e) {
            // reset dirty state to not end up in a deadlocked state and then rethrow
            dirty_components.length = 0;
            flushidx = 0;
            throw e;
        }
        set_current_component(null);
        dirty_components.length = 0;
        flushidx = 0;
        while (binding_callbacks.length)
            binding_callbacks.pop()();
        // then, once components are updated, call
        // afterUpdate functions. This may cause
        // subsequent updates...
        for (let i = 0; i < render_callbacks.length; i += 1) {
            const callback = render_callbacks[i];
            if (!seen_callbacks.has(callback)) {
                // ...so guard against infinite loops
                seen_callbacks.add(callback);
                callback();
            }
        }
        render_callbacks.length = 0;
    } while (dirty_components.length);
    while (flush_callbacks.length) {
        flush_callbacks.pop()();
    }
    update_scheduled = false;
    seen_callbacks.clear();
    set_current_component(saved_component);
}
function update($$) {
    if ($$.fragment !== null) {
        $$.update();
        run_all($$.before_update);
        const dirty = $$.dirty;
        $$.dirty = [-1];
        $$.fragment && $$.fragment.p($$.ctx, dirty);
        $$.after_update.forEach(add_render_callback);
    }
}
/**
 * Useful for example to execute remaining `afterUpdate` callbacks before executing `destroy`.
 */
function flush_render_callbacks(fns) {
    const filtered = [];
    const targets = [];
    render_callbacks.forEach((c) => fns.indexOf(c) === -1 ? filtered.push(c) : targets.push(c));
    targets.forEach((c) => c());
    render_callbacks = filtered;
}
const outroing = new Set();
let outros;
function group_outros() {
    outros = {
        r: 0,
        c: [],
        p: outros // parent group
    };
}
function check_outros() {
    if (!outros.r) {
        run_all(outros.c);
    }
    outros = outros.p;
}
function transition_in(block, local) {
    if (block && block.i) {
        outroing.delete(block);
        block.i(local);
    }
}
function transition_out(block, local, detach, callback) {
    if (block && block.o) {
        if (outroing.has(block))
            return;
        outroing.add(block);
        outros.c.push(() => {
            outroing.delete(block);
            if (callback) {
                if (detach)
                    block.d(1);
                callback();
            }
        });
        block.o(local);
    }
    else if (callback) {
        callback();
    }
}
function create_component(block) {
    block && block.c();
}
function mount_component(component, target, anchor, customElement) {
    const { fragment, after_update } = component.$$;
    fragment && fragment.m(target, anchor);
    if (!customElement) {
        // onMount happens before the initial afterUpdate
        add_render_callback(() => {
            const new_on_destroy = component.$$.on_mount.map(run).filter(is_function);
            // if the component was destroyed immediately
            // it will update the `$$.on_destroy` reference to `null`.
            // the destructured on_destroy may still reference to the old array
            if (component.$$.on_destroy) {
                component.$$.on_destroy.push(...new_on_destroy);
            }
            else {
                // Edge case - component was destroyed immediately,
                // most likely as a result of a binding initialising
                run_all(new_on_destroy);
            }
            component.$$.on_mount = [];
        });
    }
    after_update.forEach(add_render_callback);
}
function destroy_component(component, detaching) {
    const $$ = component.$$;
    if ($$.fragment !== null) {
        flush_render_callbacks($$.after_update);
        run_all($$.on_destroy);
        $$.fragment && $$.fragment.d(detaching);
        // TODO null out other refs, including component.$$ (but need to
        // preserve final state?)
        $$.on_destroy = $$.fragment = null;
        $$.ctx = [];
    }
}
function make_dirty(component, i) {
    if (component.$$.dirty[0] === -1) {
        dirty_components.push(component);
        schedule_update();
        component.$$.dirty.fill(0);
    }
    component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
}
function init(component, options, instance, create_fragment, not_equal, props, append_styles, dirty = [-1]) {
    const parent_component = current_component;
    set_current_component(component);
    const $$ = component.$$ = {
        fragment: null,
        ctx: [],
        // state
        props,
        update: noop,
        not_equal,
        bound: blank_object(),
        // lifecycle
        on_mount: [],
        on_destroy: [],
        on_disconnect: [],
        before_update: [],
        after_update: [],
        context: new Map(options.context || (parent_component ? parent_component.$$.context : [])),
        // everything else
        callbacks: blank_object(),
        dirty,
        skip_bound: false,
        root: options.target || parent_component.$$.root
    };
    append_styles && append_styles($$.root);
    let ready = false;
    $$.ctx = instance
        ? instance(component, options.props || {}, (i, ret, ...rest) => {
            const value = rest.length ? rest[0] : ret;
            if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                if (!$$.skip_bound && $$.bound[i])
                    $$.bound[i](value);
                if (ready)
                    make_dirty(component, i);
            }
            return ret;
        })
        : [];
    $$.update();
    ready = true;
    run_all($$.before_update);
    // `false` as a special case of no DOM component
    $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
    if (options.target) {
        if (options.hydrate) {
            const nodes = children(options.target);
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.l(nodes);
            nodes.forEach(detach);
        }
        else {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.c();
        }
        if (options.intro)
            transition_in(component.$$.fragment);
        mount_component(component, options.target, options.anchor, options.customElement);
        flush();
    }
    set_current_component(parent_component);
}
/**
 * Base class for Svelte components. Used when dev=false.
 */
class SvelteComponent {
    $destroy() {
        destroy_component(this, 1);
        this.$destroy = noop;
    }
    $on(type, callback) {
        if (!is_function(callback)) {
            return noop;
        }
        const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
        callbacks.push(callback);
        return () => {
            const index = callbacks.indexOf(callback);
            if (index !== -1)
                callbacks.splice(index, 1);
        };
    }
    $set($$props) {
        if (this.$$set && !is_empty($$props)) {
            this.$$.skip_bound = true;
            this.$$set($$props);
            this.$$.skip_bound = false;
        }
    }
}

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z$1 = ".spectrum-Tooltip.svelte-13ed4ik{max-width:75vw;pointer-events:none;position:fixed;z-index:99}.spectrum-Tooltip-label.svelte-13ed4ik{overflow-wrap:word-break}.spectsrum-Tooltip.vertical.svelte-13ed4ik{padding:var(--spectrum-global-dimension-size-125) var(--spectrum-global-dimension-size-50);writing-mode:vertical-rl}";
styleInject(css_248z$1);

/* src/components/Tooltip.svelte generated by Svelte v3.59.2 */

const { window: window_1 } = globals;

function create_if_block$1(ctx) {
	let span1;
	let span0;
	let t0;
	let t1;
	let span1_class_value;
	let if_block0 = (/*direction*/ ctx[10] === "top" || /*direction*/ ctx[10] === "bottom") && create_if_block_2$1(ctx);
	let if_block1 = (/*direction*/ ctx[10] === "left" || /*direction*/ ctx[10] === "right") && create_if_block_1$1(ctx);

	return {
		c() {
			span1 = element("span");
			span0 = element("span");
			t0 = space();
			if (if_block0) if_block0.c();
			t1 = space();
			if (if_block1) if_block1.c();
			attr(span0, "class", "spectrum-Tooltip-label svelte-13ed4ik");
			attr(span1, "class", span1_class_value = "spectrum-Tooltip spectrum-Tooltip--" + /*direction*/ ctx[10] + " svelte-13ed4ik");
			set_style(span1, "top", /*top*/ ctx[6] + "px");
			set_style(span1, "left", /*left*/ ctx[7] + "px");
			toggle_class(span1, "is-open", /*isOpen*/ ctx[4]);
			toggle_class(span1, "vertical", /*vertical*/ ctx[0]);
			toggle_class(span1, "relative", /*relative*/ ctx[2]);
		},
		m(target, anchor) {
			insert(target, span1, anchor);
			append(span1, span0);
			span0.innerHTML = /*breakText*/ ctx[11];
			append(span1, t0);
			if (if_block0) if_block0.m(span1, null);
			append(span1, t1);
			if (if_block1) if_block1.m(span1, null);
			/*span1_binding*/ ctx[15](span1);
		},
		p(ctx, dirty) {
			if (dirty & /*breakText*/ 2048) span0.innerHTML = /*breakText*/ ctx[11];
			if (/*direction*/ ctx[10] === "top" || /*direction*/ ctx[10] === "bottom") {
				if (if_block0) {
					if_block0.p(ctx, dirty);
				} else {
					if_block0 = create_if_block_2$1(ctx);
					if_block0.c();
					if_block0.m(span1, t1);
				}
			} else if (if_block0) {
				if_block0.d(1);
				if_block0 = null;
			}

			if (/*direction*/ ctx[10] === "left" || /*direction*/ ctx[10] === "right") {
				if (if_block1) {
					if_block1.p(ctx, dirty);
				} else {
					if_block1 = create_if_block_1$1(ctx);
					if_block1.c();
					if_block1.m(span1, null);
				}
			} else if (if_block1) {
				if_block1.d(1);
				if_block1 = null;
			}

			if (dirty & /*direction*/ 1024 && span1_class_value !== (span1_class_value = "spectrum-Tooltip spectrum-Tooltip--" + /*direction*/ ctx[10] + " svelte-13ed4ik")) {
				attr(span1, "class", span1_class_value);
			}

			if (dirty & /*top*/ 64) {
				set_style(span1, "top", /*top*/ ctx[6] + "px");
			}

			if (dirty & /*left*/ 128) {
				set_style(span1, "left", /*left*/ ctx[7] + "px");
			}

			if (dirty & /*direction, isOpen*/ 1040) {
				toggle_class(span1, "is-open", /*isOpen*/ ctx[4]);
			}

			if (dirty & /*direction, vertical*/ 1025) {
				toggle_class(span1, "vertical", /*vertical*/ ctx[0]);
			}

			if (dirty & /*direction, relative*/ 1028) {
				toggle_class(span1, "relative", /*relative*/ ctx[2]);
			}
		},
		d(detaching) {
			if (detaching) detach(span1);
			if (if_block0) if_block0.d();
			if (if_block1) if_block1.d();
			/*span1_binding*/ ctx[15](null);
		}
	};
}

// (114:8) {#if direction === "top" || direction === "bottom"}
function create_if_block_2$1(ctx) {
	let span;
	let span_style_value;

	return {
		c() {
			span = element("span");
			attr(span, "class", "spectrum-Tooltip-tip");
			attr(span, "style", span_style_value = `left: calc(50% - ${/*offsetX*/ ctx[8]}px)`);
		},
		m(target, anchor) {
			insert(target, span, anchor);
		},
		p(ctx, dirty) {
			if (dirty & /*offsetX*/ 256 && span_style_value !== (span_style_value = `left: calc(50% - ${/*offsetX*/ ctx[8]}px)`)) {
				attr(span, "style", span_style_value);
			}
		},
		d(detaching) {
			if (detaching) detach(span);
		}
	};
}

// (115:8) {#if direction === "left" || direction === "right"}
function create_if_block_1$1(ctx) {
	let span;
	let span_style_value;

	return {
		c() {
			span = element("span");
			attr(span, "class", "spectrum-Tooltip-tip");
			attr(span, "style", span_style_value = `top: calc(50% - ${/*offsetY*/ ctx[9]}px)`);
		},
		m(target, anchor) {
			insert(target, span, anchor);
		},
		p(ctx, dirty) {
			if (dirty & /*offsetY*/ 512 && span_style_value !== (span_style_value = `top: calc(50% - ${/*offsetY*/ ctx[9]}px)`)) {
				attr(span, "style", span_style_value);
			}
		},
		d(detaching) {
			if (detaching) detach(span);
		}
	};
}

function create_fragment$1(ctx) {
	let if_block_anchor;
	let mounted;
	let dispose;
	add_render_callback(/*onwindowresize*/ ctx[14]);
	let if_block = /*text*/ ctx[1] && create_if_block$1(ctx);

	return {
		c() {
			if (if_block) if_block.c();
			if_block_anchor = empty();
		},
		m(target, anchor) {
			if (if_block) if_block.m(target, anchor);
			insert(target, if_block_anchor, anchor);

			if (!mounted) {
				dispose = listen(window_1, "resize", /*onwindowresize*/ ctx[14]);
				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (/*text*/ ctx[1]) {
				if (if_block) {
					if_block.p(ctx, dirty);
				} else {
					if_block = create_if_block$1(ctx);
					if_block.c();
					if_block.m(if_block_anchor.parentNode, if_block_anchor);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (if_block) if_block.d(detaching);
			if (detaching) detach(if_block_anchor);
			mounted = false;
			dispose();
		}
	};
}

function instance$1($$self, $$props, $$invalidate) {
	let breakText;
	let direction;
	let { text = "" } = $$props;
	let { align = "auto" } = $$props;
	let { vertical = false } = $$props;
	let { relative = false } = $$props;
	let tooltip;
	let isOpen = false;
	let top, left, offsetX = 0, offsetY = 0;
	let trigger;

	const position = (target, element) => {
		let triggerDOMrect = target.getBoundingClientRect();
		let triggerTop = triggerDOMrect.top;
		let triggerLeft = triggerDOMrect.left;
		let triggerWidth = target.offsetWidth;
		let triggerHeight = target.offsetHeight;
		let tipWidth = element.offsetWidth;
		let tipHeight = element.offsetHeight;
		if (align === "auto") getDirection(target, element);

		switch (direction) {
			case "left":
				$$invalidate(7, left = triggerLeft - tipWidth);
				$$invalidate(6, top = triggerTop + triggerHeight / 2 - tipHeight / 2);
				break;
			case "right":
				$$invalidate(7, left = triggerLeft + triggerWidth);
				$$invalidate(6, top = triggerTop + triggerHeight / 2 - tipHeight / 2);
				break;
			case "top":
				$$invalidate(7, left = triggerLeft + triggerWidth / 2 - tipWidth / 2);
				$$invalidate(6, top = triggerTop - tipHeight);
				break;
			case "bottom":
				$$invalidate(7, left = triggerLeft + triggerWidth / 2 - tipWidth / 2);
				$$invalidate(6, top = triggerTop + triggerHeight);
				break;
		}

		setWindowOffsets(element);
		$$invalidate(6, top = top + offsetY);
		$$invalidate(7, left = left + offsetX);
	};

	function setWindowOffsets(element) {
		let tipWidth = element.offsetWidth;
		let tipHeight = element.offsetHeight;

		if (tipHeight > innerHeight) {
			$$invalidate(6, top = innerHeight / 2 - tipHeight / 2);
		}

		if (tipWidth > innerWidth) {
			$$invalidate(7, left = innerWidth / 2 - tipWidth / 2);
		}

		let bottomOverflow = Math.max(0, top + tipHeight - innerHeight);
		let topOverflow = Math.min(0, top);
		let rightOverflow = Math.max(0, left + tipWidth - innerWidth);
		let leftOverflow = Math.min(0, left);
		$$invalidate(9, offsetY = !topOverflow ? -bottomOverflow : -top);
		$$invalidate(8, offsetX = !leftOverflow ? -rightOverflow : -left);
	}

	function getDirection(target, element) {
		try {
			let triggerDOMrect = target.getBoundingClientRect();
			let triggerTop = triggerDOMrect.top;
			let triggerLeft = triggerDOMrect.left;
			let triggerWidth = target.offsetWidth;
			let triggerHeight = target.offsetHeight;
			let tipWidth = element.offsetWidth;
			let tipHeight = element.offsetHeight;

			const offsets = {
				"top": triggerTop,
				"right": innerWidth - (triggerLeft + triggerWidth),
				"bottom": innerHeight - (triggerTop + triggerHeight),
				"left": triggerLeft
			};

			const spaces = {
				"top": offsets.top - tipHeight,
				"right": offsets.right - tipWidth,
				"bottom": offsets.bottom - tipHeight,
				"left": offsets.left - tipWidth
			};

			$$invalidate(10, direction = Object.keys(spaces).reduce((a, b) => spaces[a] > spaces[b] ? a : b));
		} catch(error) {
			alert(error);
		}
	}

	const handleMouseover = () => $$invalidate(4, isOpen = true);
	const handleMouseout = () => $$invalidate(4, isOpen = false);
	let innerWidth;

	function onwindowresize() {
		$$invalidate(5, innerWidth = window_1.innerWidth);
	}

	function span1_binding($$value) {
		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
			tooltip = $$value;
			$$invalidate(3, tooltip);
		});
	}

	$$self.$$set = $$props => {
		if ('text' in $$props) $$invalidate(1, text = $$props.text);
		if ('align' in $$props) $$invalidate(12, align = $$props.align);
		if ('vertical' in $$props) $$invalidate(0, vertical = $$props.vertical);
		if ('relative' in $$props) $$invalidate(2, relative = $$props.relative);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*text*/ 2) {
			$$invalidate(11, breakText = text.replace(/-/g, '-<wbr>').replace(/_/g, '-<wbr>'));
		}

		if ($$self.$$.dirty & /*align*/ 4096) {
			$$invalidate(10, direction = align);
		}

		if ($$self.$$.dirty & /*tooltip*/ 8) {
			if (tooltip) $$invalidate(13, trigger = tooltip.previousElementSibling);
		}

		if ($$self.$$.dirty & /*trigger*/ 8192) {
			if (trigger) {
				//trigger.addEventListener('resize', position(trigger, tooltip, direction))
				trigger.addEventListener('mouseover', handleMouseover);

				trigger.addEventListener('mouseout', handleMouseout);
				window.addEventListener('blur', handleMouseout);
				window.addEventListener('focus', handleMouseout);
			} //position(trigger, tooltip, direction);
		}

		if ($$self.$$.dirty & /*isOpen, trigger, tooltip*/ 8216) {
			if (isOpen) {
				position(trigger, tooltip);
			}
		}

		if ($$self.$$.dirty & /*innerWidth*/ 32) {
			$$invalidate(0, vertical = innerWidth < 134);
		}
	};

	return [
		vertical,
		text,
		relative,
		tooltip,
		isOpen,
		innerWidth,
		top,
		left,
		offsetX,
		offsetY,
		direction,
		breakText,
		align,
		trigger,
		onwindowresize,
		span1_binding
	];
}

class Tooltip extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$1, create_fragment$1, safe_not_equal, {
			text: 1,
			align: 12,
			vertical: 0,
			relative: 2
		});
	}
}

var css_248z = "button.svelte-hl54dl.svelte-hl54dl{align-content:space-around;align-items:center;display:flex;position:relative}.spectrum-ActionButton.svelte-hl54dl.svelte-hl54dl{max-width:100%;width:var(--width)}.spectrum-ActionButton-label.svelte-hl54dl.svelte-hl54dl{width:auto}.spectrum-ActionButton--emphasized.is-selected.svelte-hl54dl.svelte-hl54dl{background:var(--blue-500)}.spectrum-ActionButton.secondary.svelte-hl54dl.svelte-hl54dl{background:var(--secondary-color)}.spectrum-ActionButton.tertiary.svelte-hl54dl.svelte-hl54dl{background:var(--tertiary-color)}.spectrum-ActionButton.svelte-hl54dl:enabled .spectrum-Icon.svelte-hl54dl{color:var(--iconColor)}";
styleInject(css_248z);

/* src/components/ActionButton.svelte generated by Svelte v3.59.2 */

function create_if_block_4(ctx) {
	let svg;
	let use;
	let use_xlink_href_value;
	let svg_class_value;

	return {
		c() {
			svg = svg_element("svg");
			use = svg_element("use");
			xlink_attr(use, "xlink:href", use_xlink_href_value = `#spectrum-css-icon-CornerTriangle${/*size*/ ctx[0] == "S" ? "75" : "100"}`);
			attr(svg, "class", svg_class_value = "" + (null_to_empty(`spectrum-Icon spectrum-UIIcon-CornerTriangle${/*size*/ ctx[0] == "S" ? "75" : "100"} spectrum-ActionButton-hold`) + " svelte-hl54dl"));
			attr(svg, "focusable", "false");
			attr(svg, "aria-hidden", "true");
		},
		m(target, anchor) {
			insert(target, svg, anchor);
			append(svg, use);
		},
		p(ctx, dirty) {
			if (dirty & /*size*/ 1 && use_xlink_href_value !== (use_xlink_href_value = `#spectrum-css-icon-CornerTriangle${/*size*/ ctx[0] == "S" ? "75" : "100"}`)) {
				xlink_attr(use, "xlink:href", use_xlink_href_value);
			}

			if (dirty & /*size*/ 1 && svg_class_value !== (svg_class_value = "" + (null_to_empty(`spectrum-Icon spectrum-UIIcon-CornerTriangle${/*size*/ ctx[0] == "S" ? "75" : "100"} spectrum-ActionButton-hold`) + " svelte-hl54dl"))) {
				attr(svg, "class", svg_class_value);
			}
		},
		d(detaching) {
			if (detaching) detach(svg);
		}
	};
}

// (49:4) {#if iconName}
function create_if_block_3(ctx) {
	let svg;
	let use;
	let use_xlink_href_value;
	let svg_class_value;

	return {
		c() {
			svg = svg_element("svg");
			use = svg_element("use");
			xlink_attr(use, "xlink:href", use_xlink_href_value = "#spectrum-icon-18-" + /*iconName*/ ctx[6]);
			attr(svg, "class", svg_class_value = "spectrum-Icon spectrum-Icon--size" + /*size*/ ctx[0] + " svelte-hl54dl");
			attr(svg, "focusable", "false");
			attr(svg, "aria-hidden", "true");
			attr(svg, "aria-label", "Edit");
		},
		m(target, anchor) {
			insert(target, svg, anchor);
			append(svg, use);
		},
		p(ctx, dirty) {
			if (dirty & /*iconName*/ 64 && use_xlink_href_value !== (use_xlink_href_value = "#spectrum-icon-18-" + /*iconName*/ ctx[6])) {
				xlink_attr(use, "xlink:href", use_xlink_href_value);
			}

			if (dirty & /*size*/ 1 && svg_class_value !== (svg_class_value = "spectrum-Icon spectrum-Icon--size" + /*size*/ ctx[0] + " svelte-hl54dl")) {
				attr(svg, "class", svg_class_value);
			}
		},
		d(detaching) {
			if (detaching) detach(svg);
		}
	};
}

// (54:4) {#if label && !iconOnly}
function create_if_block_2(ctx) {
	let span;
	let t;

	return {
		c() {
			span = element("span");
			t = text(/*label*/ ctx[5]);
			attr(span, "class", "spectrum-ActionButton-label svelte-hl54dl");
		},
		m(target, anchor) {
			insert(target, span, anchor);
			append(span, t);
		},
		p(ctx, dirty) {
			if (dirty & /*label*/ 32) set_data(t, /*label*/ ctx[5]);
		},
		d(detaching) {
			if (detaching) detach(span);
		}
	};
}

// (56:4) {#if relativeTooltip}
function create_if_block_1(ctx) {
	let div;
	let span0;
	let t0;
	let t1;
	let span1;
	let div_class_value;

	return {
		c() {
			div = element("div");
			span0 = element("span");
			t0 = text(/*label*/ ctx[5]);
			t1 = space();
			span1 = element("span");
			attr(span0, "class", "spectrum-Tooltip-label");
			attr(span1, "class", "spectrum-Tooltip-tip");

			attr(div, "class", div_class_value = "spectrum-Tooltip spectrum-Tooltip--" + (/*tooltipDirection*/ ctx[17] === "auto"
			? "top"
			: /*tooltipDirection*/ ctx[17]) + " svelte-hl54dl");
		},
		m(target, anchor) {
			insert(target, div, anchor);
			append(div, span0);
			append(span0, t0);
			append(div, t1);
			append(div, span1);
		},
		p(ctx, dirty) {
			if (dirty & /*label*/ 32) set_data(t0, /*label*/ ctx[5]);

			if (dirty & /*tooltipDirection*/ 131072 && div_class_value !== (div_class_value = "spectrum-Tooltip spectrum-Tooltip--" + (/*tooltipDirection*/ ctx[17] === "auto"
			? "top"
			: /*tooltipDirection*/ ctx[17]) + " svelte-hl54dl")) {
				attr(div, "class", div_class_value);
			}
		},
		d(detaching) {
			if (detaching) detach(div);
		}
	};
}

// (63:0) {#if iconOnly || !hideTooltip && !relativeTooltip}
function create_if_block(ctx) {
	let tooltip;
	let current;

	tooltip = new Tooltip({
			props: {
				relative: true,
				text: /*label*/ ctx[5],
				align: /*tooltipDirection*/ ctx[17]
			}
		});

	return {
		c() {
			create_component(tooltip.$$.fragment);
		},
		m(target, anchor) {
			mount_component(tooltip, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const tooltip_changes = {};
			if (dirty & /*label*/ 32) tooltip_changes.text = /*label*/ ctx[5];
			if (dirty & /*tooltipDirection*/ 131072) tooltip_changes.align = /*tooltipDirection*/ ctx[17];
			tooltip.$set(tooltip_changes);
		},
		i(local) {
			if (current) return;
			transition_in(tooltip.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(tooltip.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(tooltip, detaching);
		}
	};
}

function create_fragment(ctx) {
	let button;
	let t0;
	let t1;
	let t2;
	let t3;
	let button_class_value;
	let button_style_value;
	let t4;
	let if_block4_anchor;
	let current;
	let mounted;
	let dispose;
	let if_block0 = /*hold*/ ctx[4] && create_if_block_4(ctx);
	let if_block1 = /*iconName*/ ctx[6] && create_if_block_3(ctx);
	let if_block2 = /*label*/ ctx[5] && !/*iconOnly*/ ctx[2] && create_if_block_2(ctx);
	const default_slot_template = /*#slots*/ ctx[20].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[19], null);
	let if_block3 = /*relativeTooltip*/ ctx[18] && create_if_block_1(ctx);
	let if_block4 = (/*iconOnly*/ ctx[2] || !/*hideTooltip*/ ctx[3] && !/*relativeTooltip*/ ctx[18]) && create_if_block(ctx);

	return {
		c() {
			button = element("button");
			if (if_block0) if_block0.c();
			t0 = space();
			if (if_block1) if_block1.c();
			t1 = space();
			if (if_block2) if_block2.c();
			t2 = space();
			if (default_slot) default_slot.c();
			t3 = space();
			if (if_block3) if_block3.c();
			t4 = space();
			if (if_block4) if_block4.c();
			if_block4_anchor = empty();
			attr(button, "class", button_class_value = "spectrum-ActionButton spectrum-ActionButton--size" + /*size*/ ctx[0] + " svelte-hl54dl");
			button.disabled = /*disabled*/ ctx[11];

			attr(button, "style", button_style_value = "--iconColor: " + (/*iconColor*/ ctx[7]
			? /*iconColor*/ ctx[7]
			: "var(--spectrum-actionbutton-m-texticon-icon-color-hover, var(--spectrum-alias-component-icon-color-hover))") + "; --secondary-color: " + /*secondaryColor*/ ctx[14] + "; --tertiary-color: " + /*tertiaryColor*/ ctx[15] + "; " + (/*margin*/ ctx[12]
			? `margin: ${/*margin*/ ctx[12]}`
			: "") + "; --width: " + (/*width*/ ctx[13] ? /*width*/ ctx[13] : "inherit") + ";");

			toggle_class(button, "spectrum-ActionButton-iconOnly", /*iconOnly*/ ctx[2]);
			toggle_class(button, "spectrum-ActionGroup-item", /*groupItem*/ ctx[1]);
			toggle_class(button, "spectrum-ActionButton--emphasized", /*emphasized*/ ctx[8]);
			toggle_class(button, "spectrum-ActionButton--quiet", /*quiet*/ ctx[9]);
			toggle_class(button, "is-selected", /*isSelected*/ ctx[10]);
			toggle_class(button, "secondary", /*secondary*/ ctx[16]);
			toggle_class(button, "u-tooltip-showOnHover", /*relativeTooltip*/ ctx[18]);
		},
		m(target, anchor) {
			insert(target, button, anchor);
			if (if_block0) if_block0.m(button, null);
			append(button, t0);
			if (if_block1) if_block1.m(button, null);
			append(button, t1);
			if (if_block2) if_block2.m(button, null);
			append(button, t2);

			if (default_slot) {
				default_slot.m(button, null);
			}

			append(button, t3);
			if (if_block3) if_block3.m(button, null);
			insert(target, t4, anchor);
			if (if_block4) if_block4.m(target, anchor);
			insert(target, if_block4_anchor, anchor);
			current = true;

			if (!mounted) {
				dispose = [
					listen(button, "click", /*click_handler*/ ctx[21]),
					listen(button, "mousedown", /*mousedown_handler*/ ctx[22]),
					listen(button, "mouseup", /*mouseup_handler*/ ctx[23]),
					listen(button, "dblclick", /*dblclick_handler*/ ctx[24])
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (/*hold*/ ctx[4]) {
				if (if_block0) {
					if_block0.p(ctx, dirty);
				} else {
					if_block0 = create_if_block_4(ctx);
					if_block0.c();
					if_block0.m(button, t0);
				}
			} else if (if_block0) {
				if_block0.d(1);
				if_block0 = null;
			}

			if (/*iconName*/ ctx[6]) {
				if (if_block1) {
					if_block1.p(ctx, dirty);
				} else {
					if_block1 = create_if_block_3(ctx);
					if_block1.c();
					if_block1.m(button, t1);
				}
			} else if (if_block1) {
				if_block1.d(1);
				if_block1 = null;
			}

			if (/*label*/ ctx[5] && !/*iconOnly*/ ctx[2]) {
				if (if_block2) {
					if_block2.p(ctx, dirty);
				} else {
					if_block2 = create_if_block_2(ctx);
					if_block2.c();
					if_block2.m(button, t2);
				}
			} else if (if_block2) {
				if_block2.d(1);
				if_block2 = null;
			}

			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope*/ 524288)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[19],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[19])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[19], dirty, null),
						null
					);
				}
			}

			if (/*relativeTooltip*/ ctx[18]) {
				if (if_block3) {
					if_block3.p(ctx, dirty);
				} else {
					if_block3 = create_if_block_1(ctx);
					if_block3.c();
					if_block3.m(button, null);
				}
			} else if (if_block3) {
				if_block3.d(1);
				if_block3 = null;
			}

			if (!current || dirty & /*size*/ 1 && button_class_value !== (button_class_value = "spectrum-ActionButton spectrum-ActionButton--size" + /*size*/ ctx[0] + " svelte-hl54dl")) {
				attr(button, "class", button_class_value);
			}

			if (!current || dirty & /*disabled*/ 2048) {
				button.disabled = /*disabled*/ ctx[11];
			}

			if (!current || dirty & /*iconColor, secondaryColor, tertiaryColor, margin, width*/ 61568 && button_style_value !== (button_style_value = "--iconColor: " + (/*iconColor*/ ctx[7]
			? /*iconColor*/ ctx[7]
			: "var(--spectrum-actionbutton-m-texticon-icon-color-hover, var(--spectrum-alias-component-icon-color-hover))") + "; --secondary-color: " + /*secondaryColor*/ ctx[14] + "; --tertiary-color: " + /*tertiaryColor*/ ctx[15] + "; " + (/*margin*/ ctx[12]
			? `margin: ${/*margin*/ ctx[12]}`
			: "") + "; --width: " + (/*width*/ ctx[13] ? /*width*/ ctx[13] : "inherit") + ";")) {
				attr(button, "style", button_style_value);
			}

			if (!current || dirty & /*size, iconOnly*/ 5) {
				toggle_class(button, "spectrum-ActionButton-iconOnly", /*iconOnly*/ ctx[2]);
			}

			if (!current || dirty & /*size, groupItem*/ 3) {
				toggle_class(button, "spectrum-ActionGroup-item", /*groupItem*/ ctx[1]);
			}

			if (!current || dirty & /*size, emphasized*/ 257) {
				toggle_class(button, "spectrum-ActionButton--emphasized", /*emphasized*/ ctx[8]);
			}

			if (!current || dirty & /*size, quiet*/ 513) {
				toggle_class(button, "spectrum-ActionButton--quiet", /*quiet*/ ctx[9]);
			}

			if (!current || dirty & /*size, isSelected*/ 1025) {
				toggle_class(button, "is-selected", /*isSelected*/ ctx[10]);
			}

			if (!current || dirty & /*size, secondary*/ 65537) {
				toggle_class(button, "secondary", /*secondary*/ ctx[16]);
			}

			if (!current || dirty & /*size, relativeTooltip*/ 262145) {
				toggle_class(button, "u-tooltip-showOnHover", /*relativeTooltip*/ ctx[18]);
			}

			if (/*iconOnly*/ ctx[2] || !/*hideTooltip*/ ctx[3] && !/*relativeTooltip*/ ctx[18]) {
				if (if_block4) {
					if_block4.p(ctx, dirty);

					if (dirty & /*iconOnly, hideTooltip, relativeTooltip*/ 262156) {
						transition_in(if_block4, 1);
					}
				} else {
					if_block4 = create_if_block(ctx);
					if_block4.c();
					transition_in(if_block4, 1);
					if_block4.m(if_block4_anchor.parentNode, if_block4_anchor);
				}
			} else if (if_block4) {
				group_outros();

				transition_out(if_block4, 1, 1, () => {
					if_block4 = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			transition_in(if_block4);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			transition_out(if_block4);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(button);
			if (if_block0) if_block0.d();
			if (if_block1) if_block1.d();
			if (if_block2) if_block2.d();
			if (default_slot) default_slot.d(detaching);
			if (if_block3) if_block3.d();
			if (detaching) detach(t4);
			if (if_block4) if_block4.d(detaching);
			if (detaching) detach(if_block4_anchor);
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	let { size = "M" } = $$props;
	let { groupItem = false } = $$props;
	let { iconOnly = false } = $$props;
	let { hideTooltip = false } = $$props;
	let { hold = false } = $$props;
	let { label = "" } = $$props;
	let { iconName = "" } = $$props;
	let { iconColor = "" } = $$props;
	let { emphasized = false } = $$props;
	let { quiet = false } = $$props;
	let { isSelected = false } = $$props;
	let { disabled = false } = $$props;
	let { margin = "" } = $$props;
	let { width = "" } = $$props;
	let { secondaryColor = "var(--green-500)" } = $$props;
	let { tertiaryColor = "var(--magenta-500)" } = $$props;
	let { secondary = false } = $$props;
	let { tooltipDirection = "auto" } = $$props;
	let { relativeTooltip = false } = $$props;

	function click_handler(event) {
		bubble.call(this, $$self, event);
	}

	function mousedown_handler(event) {
		bubble.call(this, $$self, event);
	}

	function mouseup_handler(event) {
		bubble.call(this, $$self, event);
	}

	function dblclick_handler(event) {
		bubble.call(this, $$self, event);
	}

	$$self.$$set = $$props => {
		if ('size' in $$props) $$invalidate(0, size = $$props.size);
		if ('groupItem' in $$props) $$invalidate(1, groupItem = $$props.groupItem);
		if ('iconOnly' in $$props) $$invalidate(2, iconOnly = $$props.iconOnly);
		if ('hideTooltip' in $$props) $$invalidate(3, hideTooltip = $$props.hideTooltip);
		if ('hold' in $$props) $$invalidate(4, hold = $$props.hold);
		if ('label' in $$props) $$invalidate(5, label = $$props.label);
		if ('iconName' in $$props) $$invalidate(6, iconName = $$props.iconName);
		if ('iconColor' in $$props) $$invalidate(7, iconColor = $$props.iconColor);
		if ('emphasized' in $$props) $$invalidate(8, emphasized = $$props.emphasized);
		if ('quiet' in $$props) $$invalidate(9, quiet = $$props.quiet);
		if ('isSelected' in $$props) $$invalidate(10, isSelected = $$props.isSelected);
		if ('disabled' in $$props) $$invalidate(11, disabled = $$props.disabled);
		if ('margin' in $$props) $$invalidate(12, margin = $$props.margin);
		if ('width' in $$props) $$invalidate(13, width = $$props.width);
		if ('secondaryColor' in $$props) $$invalidate(14, secondaryColor = $$props.secondaryColor);
		if ('tertiaryColor' in $$props) $$invalidate(15, tertiaryColor = $$props.tertiaryColor);
		if ('secondary' in $$props) $$invalidate(16, secondary = $$props.secondary);
		if ('tooltipDirection' in $$props) $$invalidate(17, tooltipDirection = $$props.tooltipDirection);
		if ('relativeTooltip' in $$props) $$invalidate(18, relativeTooltip = $$props.relativeTooltip);
		if ('$$scope' in $$props) $$invalidate(19, $$scope = $$props.$$scope);
	};

	return [
		size,
		groupItem,
		iconOnly,
		hideTooltip,
		hold,
		label,
		iconName,
		iconColor,
		emphasized,
		quiet,
		isSelected,
		disabled,
		margin,
		width,
		secondaryColor,
		tertiaryColor,
		secondary,
		tooltipDirection,
		relativeTooltip,
		$$scope,
		slots,
		click_handler,
		mousedown_handler,
		mouseup_handler,
		dblclick_handler
	];
}

class ActionButton extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance, create_fragment, safe_not_equal, {
			size: 0,
			groupItem: 1,
			iconOnly: 2,
			hideTooltip: 3,
			hold: 4,
			label: 5,
			iconName: 6,
			iconColor: 7,
			emphasized: 8,
			quiet: 9,
			isSelected: 10,
			disabled: 11,
			margin: 12,
			width: 13,
			secondaryColor: 14,
			tertiaryColor: 15,
			secondary: 16,
			tooltipDirection: 17,
			relativeTooltip: 18
		});
	}
}

export { ActionButton, Tooltip };
