// rollup.config.js
import { createRequire } from "module";
const require = createRequire(import.meta.url);

import svelte from 'rollup-plugin-svelte';
import commonjs from '@rollup/plugin-commonjs';
import resolve from '@rollup/plugin-node-resolve';
import sveltePreprocess from 'svelte-preprocess';
import typescript from '@rollup/plugin-typescript';
import json from '@rollup/plugin-json';

import postcss from 'rollup-plugin-postcss';

// dependencies
const fs = require("fs")
const postcssglobal = require("postcss")
const atImport = require("postcss-import")

// css to be processed
const globalStyles = fs.readFileSync("src/styles/global.css", "utf8")

// Read the content of the existing CSS file

export default {
  input: 'src/index.ts',
  output: {
    file: 'dist/index.js',
    format: 'es' // Output format is ES module
  },
  plugins: [
    svelte({
      preprocess: sveltePreprocess(),
    }), 
    resolve({ browser: true }),
    commonjs(),
    typescript(),
    json(),
    postcssglobal()
      .use(atImport())
      .process(globalStyles, {
        // `from` option is needed here
        from: "src/styles/global.css"
      })
      .then((result) => {
        const output = result.css
        fs.writeFileSync("dist/spectrum-ui-components.css", result.css)
      }),
    postcss({
      minimize: true,
      // Extract CSS into a separate file
      extract: false,
    })
    ],
  };
